@@ -65,11 +65,15 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 # URL: http://tungwaiyip.info/software/HTMLTestRunner.html
 
 __author__ = "Wai Yip Tung,  Findyou，Adil, Javen"
-__version__ = "0.8.2.3"
+__version__ = "1.3"
 
 """
 Change History
-Version 0.8.2.3 -Javen
+
+Version 1.3 -Javen
+* 添加日志输出
+
+Version 1.2 -Javen
 * 添加skip状态的用例
 
 Version 0.8.2.1 -Findyou
@@ -93,6 +97,7 @@ import time
 import unittest
 from xml.sax import saxutils
 import copy
+import logging
 
 
 # ------------------------------------------------------------------------
@@ -246,6 +251,9 @@ window.onload = function(){
                                     }]
                             };
     myChart.setOption(option_case_res);
+
+    // 通过的用例，默认不展开日志 -by Javen
+    $("div[id^='div_p']").attr('class', 'collapse');
 }
 
 
@@ -497,7 +505,7 @@ table       { font-size: 100%; }
     <div id='div_%(tid)s' class="collapse">  -->
 
     <!-- 默认展开错误信息 -->
-    <button id='btn_%(tid)s' type="button"  class="btn %(btn_type)s btn-xs" data-toggle="collapse" data-target='#div_%(tid)s'>%(status)s</button>
+    <button id='btn_%(tid)s' type="button"  class="btn %(btn_type)s btn-xs" data-toggle="collapse" data-target='#div_%(tid)s'>%(status)s - 展开/收起日志</button>
     <div id='div_%(tid)s' class="collapse in" style='text-align: left; color:red;cursor:pointer'>
     <pre>
     %(script)s
@@ -548,7 +556,6 @@ class _TestResult(TestResult):
         self.failure_count = 0
         self.error_count = 0
         self.skipped_count = 0
-
         self.verbosity = verbosity
 
         # result is a list of result in 4 tuple
@@ -567,6 +574,9 @@ class _TestResult(TestResult):
         self.trys = 0
         self.istry = False
 
+        # 添加日志-by Javen
+        self.logger = logging.getLogger('haohan.log')
+
     def startTest(self, test):
         TestResult.startTest(self, test)
         # just one buffer for both stdout and stderr
@@ -578,6 +588,15 @@ class _TestResult(TestResult):
         sys.stdout = stdout_redirector
         sys.stderr = stderr_redirector
 
+        # 添加日志-by Javen
+        self.log_cap = io.StringIO()
+        self.ch = logging.StreamHandler(self.log_cap)
+        self.ch.setLevel(logging.INFO)
+        formatter = logging.Formatter('[%(levelname)s][%(asctime)s] ---> %(message)s')
+        # "%(asctime)s - %(module)s[line:%(lineno)d] - %(levelname)s: %(message)s"
+        self.ch.setFormatter(formatter)
+        self.logger.addHandler(self.ch)
+
     def complete_output(self):
         """
         Disconnect output redirection and return buffer.
@@ -588,7 +607,8 @@ class _TestResult(TestResult):
             sys.stderr = self.stderr0
             self.stdout0 = None
             self.stderr0 = None
-        return self.outputBuffer.getvalue()
+        # 添加日志输出-by Javen
+        return self.outputBuffer.getvalue() + '\n' + self.log_cap.getvalue()
 
     def stopTest(self, test):
         # Usually one of addSuccess, addError or addFailure would have been called.
@@ -614,9 +634,10 @@ class _TestResult(TestResult):
                 self.istry = False
                 self.trys = 0
         self.complete_output()
+        self.logger.removeHandler(self.ch)  # 清除日志handler-by Javen
 
     def addSuccess(self, test):
-        self.istry=False
+        self.istry = False
         self.success_count += 1
         TestResult.addSuccess(self, test)
         output = self.complete_output()
@@ -815,7 +836,7 @@ class HTMLTestRunner(Template_mixin):
             desc = doc and '%s: %s' % (name, doc) or name
             row = self.REPORT_CLASS_TMPL % dict(
                 style=(ne > 0 and 'errorClass') or (nf > 0 and 'failClass') or (np > 0 and 'passClass') or (
-                            nk > 0 and 'skipClass'),
+                        nk > 0 and 'skipClass'),
                 desc=desc,
                 count=np + nf + ne + nk,
                 Pass=np,
@@ -845,7 +866,7 @@ class HTMLTestRunner(Template_mixin):
         has_output = bool(o or e)
         # ID修改点为下划线,支持Bootstrap折叠展开特效
         tid = ((n == 0 and 'p') or (n == 1 and 'f') or (n == 3 and 's') or (n == 2 and 'e')) + 't%s_%s' % (
-        cid + 1, tid + 1)
+            cid + 1, tid + 1)
         name = t.id().split('.')[-1]
         doc = t.shortDescription() or ""
         desc = doc and ('%s: %s' % (name, doc)) or name
@@ -877,11 +898,12 @@ class HTMLTestRunner(Template_mixin):
             tid=tid,
             Class=(n == 0 and 'hiddenRow' or ''),
             style=(n == 2 and 'errorCase') or (n == 1 and 'failCase') or (n == 0 and 'passCase') or (
-                        n == 3 and 'skipCase'),
+                    n == 3 and 'skipCase'),
             desc=desc,
             script=script,
             status=self.STATUS[n],
-            btn_type=(n == 1 and 'btn-danger') or (n == 2 and 'btn-warning') or (n == 3 and 'skip_btn')
+            btn_type=(n == 0 and 'btn-success') or (n == 1 and 'btn-danger') or (n == 2 and 'btn-warning') or (
+                        n == 3 and 'skip_btn')
         )
         rows.append(row)
         if not has_output:
